<?xml version="1.0" encoding="Shift_JIS" ?>
		<!-- ezadd-fo.xsl	-->
<xsl:stylesheet version="1.0"
		 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		 xmlns:fo="http://www.w3.org/1999/XSL/Format"
		>
<xsl:output method="xml" encoding="utf-8" indent="yes"/>
<xsl:variable name="page-height" select="'297'"/>
<xsl:variable name="page-width" select="'210'"/>
<xsl:variable name="margin-top" select="'8'"/>
<xsl:variable name="margin-bottom">
	<xsl:value-of select="($page-height div 2) + 6"/>
</xsl:variable>
<xsl:variable name="margin-left" select="'8'"/>
<xsl:variable name="margin-right">
	<xsl:value-of select="$page-width - (160 div 2) + 8"/>
</xsl:variable>

<xsl:template match="list">
	<fo:root>
		<xsl:call-template name="layoutMasterSet"/>
		<xsl:call-template name="pageSequence"/>
	</fo:root>
</xsl:template>

<xsl:template name="layoutMasterSet">
	<fo:layout-master-set>
		<fo:simple-page-master master-name="one">
			<xsl:attribute name="page-height">
				<xsl:value-of select="concat($page-height, 'mm')"/>
			</xsl:attribute>
			<xsl:attribute name="page-width">
				<xsl:value-of select="concat($page-width, 'mm')"/>
			</xsl:attribute>
			<xsl:attribute name="margin-top">
				<xsl:value-of select="concat($margin-top, 'mm')"/>
			</xsl:attribute>
			<xsl:attribute name="margin-bottom">
				<xsl:value-of select="concat($margin-bottom, 'mm')"/>
			</xsl:attribute>
			<xsl:attribute name="margin-left">
				<xsl:value-of select="concat($margin-left, 'mm')"/>
			</xsl:attribute>
			<xsl:attribute name="margin-right">
				<xsl:value-of select="concat($margin-right, 'mm')"/>
			</xsl:attribute>
			<fo:region-body>
				<xsl:attribute name="margin-top">
					<xsl:value-of select="'0'"/>
				</xsl:attribute>
				<xsl:attribute name="margin-bottom">
					<xsl:value-of select="'0'"/>
				</xsl:attribute>
			</fo:region-body>
		</fo:simple-page-master>
	</fo:layout-master-set>
</xsl:template>

<xsl:template name="pageSequence">
	<fo:page-sequence master-reference="one">
		<xsl:call-template name="font"/>
		<xsl:call-template name="flow"/>
	</fo:page-sequence>
</xsl:template>

<xsl:template name="flow">
	<fo:flow flow-name="xsl-region-body">
		<xsl:apply-templates select="date"/>
		<xsl:apply-templates select="add | id | page"/>
		<xsl:call-template name="fin"/>
	</fo:flow>
</xsl:template>

<xsl:template match="date">
	<fo:block text-align="right">
		<xsl:text>[</xsl:text>
		<xsl:value-of select="normalize-space(.)"/>
		<xsl:text>]</xsl:text>
	</fo:block>
</xsl:template>

<xsl:template match="add">
	<fo:block space-before="5pt">
		<xsl:call-template name="font-weight-bold"/>
		<xsl:text>[Z^]</xsl:text>
	</fo:block>
	<xsl:apply-templates select="p | page"/>
</xsl:template>

<xsl:template match="p">
	<xsl:if test="normalize-space(d) = 'y'">
		<xsl:call-template name="pProc"/>
	</xsl:if>
</xsl:template>

<xsl:template name="pProc">
	<fo:block space-after="6pt">
		<fo:table table-layout="fixed" width="100%" border-collapse="separate">
			<fo:table-column column-width="60%"/>
			<fo:table-column column-width="40%"/>
			<fo:table-body>
				<xsl:apply-templates select="n"/>
			</fo:table-body>
		</fo:table>
	</fo:block>
</xsl:template>

<xsl:template match="n">
	<fo:table-row>
		<fo:table-cell>
			<fo:block>
				<xsl:value-of select="."/>
			</fo:block>
		</fo:table-cell>
		<fo:table-cell text-align="right">
			<fo:block>
				<xsl:apply-templates select="../t"/>
			</fo:block>
		</fo:table-cell>
	</fo:table-row>
	<xsl:apply-templates select="../a | ../o"/>
	<xsl:apply-templates select="../c"/>
</xsl:template>

<xsl:template match="a">
	<xsl:if test="string-length(normalize-space(.)) != 0">
		<fo:table-row>
			<fo:table-cell number-columns-spanned="2">
				<fo:block>
					<xsl:value-of select="."/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:if>
</xsl:template>

<xsl:template match="o">
	<xsl:if test="string-length(normalize-space(n)) != 0
				or string-length(normalize-space(t)) != 0">
		<fo:table-row>
			<xsl:apply-templates select="n"/>
		</fo:table-row>
	</xsl:if>
</xsl:template>

<xsl:template match="o/n">
	<fo:table-cell>
		<fo:block>
			<xsl:value-of select="."/>
		</fo:block>
	</fo:table-cell>
	<xsl:apply-templates select="../t"/>
</xsl:template>

<xsl:template match="o/t">
	<fo:table-cell>
		<fo:block text-align="right">
			<xsl:value-of select="."/>
		</fo:block>
	</fo:table-cell>
</xsl:template>

<xsl:template match="p/c">
	<xsl:if test="string-length(normalize-space(.)) != 0">
		<fo:table-row>
			<fo:table-cell number-columns-spanned="2">
				<fo:block>
					<xsl:value-of select="."/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:if>
</xsl:template>

<xsl:template match="id">
	<fo:block space-before="5pt">
		<xsl:call-template name="font-weight-bold"/>
		<xsl:text>[]</xsl:text>
	</fo:block>
	<xsl:apply-templates select="i | page"/>
</xsl:template>

<xsl:template match="i">
	<xsl:if test="normalize-space(d) = 'y'">
			<xsl:apply-templates select="l | c"/>
	</xsl:if>
</xsl:template>

<xsl:template match="l">
	<fo:block>
		<xsl:value-of select="."/>
		<xsl:text>@</xsl:text>
		<xsl:value-of select="../n"/>
	</fo:block>
</xsl:template>

<xsl:template match="c">
	<xsl:if test="string-length(normalize-space(.)) != 0">
		<fo:block>
			<xsl:text>@</xsl:text>
			<xsl:value-of select="."/>
		</fo:block>
	</xsl:if>
</xsl:template>

<xsl:template name="fin">
	<fo:block font-size="7pt" text-align="right" space-before="5pt">
		<xsl:call-template name="font-family"/>
		<xsl:text>[Typesetting by EZADD]</xsl:text>
	</fo:block>
</xsl:template>

<xsl:template match="page">
	<fo:block break-before="page">@</fo:block>
</xsl:template>

<xsl:template name="font">
	<xsl:call-template name="font-family"/>
	<xsl:call-template name="font-size"/>
	<xsl:apply-templates select="@font-weight"/>
</xsl:template>

<xsl:template name="font-family">
	<xsl:attribute name="font-family">
		<xsl:value-of select="'MS-Mincho'"/>
	</xsl:attribute>
</xsl:template>

<xsl:template name="font-size">
	<xsl:attribute name="font-size">
		<xsl:value-of select="'8pt'"/>
	</xsl:attribute>
</xsl:template>

<xsl:template name="font-weight-bold">
	<xsl:attribute name="font-weight">
		<xsl:value-of select="'bolder'"/>
	</xsl:attribute>
</xsl:template>

</xsl:stylesheet>
